@@ -54,11 +54,11 @@ def BrowserGCM(headless=True):
 
         return webdriver.Chrome(options=chrome_options)
     try:
-        _browser = init_browser(headless)
-        yield _browser
+        browser_cm = init_browser(headless)
+        yield browser_cm
     except Exception as exc:
         print(f'Failed init browser ?? {exc}')
         raise BrowserException(exc)
     finally:
-        if _browser:
-            _browser.quit()
+        if browser_cm:
+            browser_cm.quit()
